@@ -1,5 +1,5 @@
 /*	HomeBank -- Free, easy, personal accounting for everyone.
- *	Copyright (C) 1995-2015 Maxime DOYEN
+ *	Copyright (C) 1995-2016 Maxime DOYEN
  *
  *	This file is part of HomeBank.
  *
@@ -67,12 +67,377 @@ static void register_panel_export_csv(GtkWidget *widget, gpointer user_data);
 static void register_panel_make_archive(GtkWidget *widget, gpointer user_data);
 
 static void status_selected_foreach_func (GtkTreeModel	*model, GtkTreePath	 *path, GtkTreeIter	 *iter, gpointer userdata);
-Transaction *get_active_transaction(GtkTreeView *treeview);
+
 static void register_panel_selection(GtkTreeSelection *treeselection, gpointer user_data);
 static void register_panel_onRowActivated (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *col, gpointer userdata);
 
 
 
+
+static void ui_multipleedit_dialog_update( GtkWidget *widget, gpointer user_data )
+{
+struct ui_multipleedit_dialog_data *data;
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	DB( g_print ("\n[ui-multipleedit] update\n") );
+
+	if(data->NU_mode && data->ST_info)
+	{
+		gtk_widget_set_sensitive (data->NU_mode, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_mode)) );
+		gtk_widget_set_sensitive (data->ST_info, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_info)) );
+	}
+
+	if(data->PO_pay)
+		gtk_widget_set_sensitive (data->PO_pay , gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_pay )) );
+
+	if(data->PO_cat)
+		gtk_widget_set_sensitive (data->PO_cat , gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_cat )) );
+
+	if(data->ST_tags)
+		gtk_widget_set_sensitive (data->ST_tags, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_tags)) );
+
+	if(data->ST_memo)
+		gtk_widget_set_sensitive (data->ST_memo, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_memo)) );
+}
+
+
+static void ui_multipleedit_dialog_init( GtkWidget *widget, gpointer user_data )
+{
+struct ui_multipleedit_dialog_data *data;
+GtkTreeModel *model;
+GList *selection, *list;
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	DB( g_print ("\n[ui-multipleedit] init\n") );
+
+	model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->treeview));
+	selection = gtk_tree_selection_get_selected_rows(gtk_tree_view_get_selection(GTK_TREE_VIEW(data->treeview)), &model);
+
+	data->has_xfer = FALSE;
+
+	list = g_list_last(selection);
+	while(list != NULL)
+	{
+	Transaction *entry;
+	GtkTreeIter iter;
+
+		gtk_tree_model_get_iter(model, &iter, list->data);
+		gtk_tree_model_get(model, &iter, LST_DSPOPE_DATAS, &entry, -1);
+
+		if(entry->paymode == PAYMODE_INTXFER)
+			data->has_xfer = TRUE;
+
+		list = g_list_previous(list);
+	}
+
+	g_list_foreach(selection, (GFunc)gtk_tree_path_free, NULL);
+	g_list_free(selection);
+
+}
+
+
+static void ui_multipleedit_dialog_apply( GtkWidget *widget, gpointer user_data )
+{
+struct ui_multipleedit_dialog_data *data;
+GtkTreeModel *model;
+GList *selection, *list;
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	DB( g_print ("\n[ui-multipleedit] apply\n") );
+
+	model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->treeview));
+	selection = gtk_tree_selection_get_selected_rows(gtk_tree_view_get_selection(GTK_TREE_VIEW(data->treeview)), &model);
+
+	list = g_list_last(selection);
+	while(list != NULL)
+	{
+	Transaction *txn;
+	GtkTreeIter iter;
+	const gchar *txt;
+	gboolean change = FALSE;
+
+		gtk_tree_model_get_iter(model, &iter, list->data);
+		gtk_tree_model_get(model, &iter, LST_DSPOPE_DATAS, &txn, -1);
+
+		DB( g_print(" modifying %s %.2f\n", txn->wording, txn->amount) );
+
+		if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_mode)) )
+		{
+			txn->paymode = gtk_combo_box_get_active(GTK_COMBO_BOX(data->NU_mode));
+			change = TRUE;
+		}
+		
+		if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_info)) )
+		{
+			txt = gtk_entry_get_text(GTK_ENTRY(data->ST_info));
+			if (txt && *txt)
+			{
+				g_free(txn->info);
+				txn->info = g_strdup(txt);
+				change = TRUE;
+			}
+		}
+
+		if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_pay)) )
+		{
+			txn->kpay = ui_pay_comboboxentry_get_key_add_new(GTK_COMBO_BOX(data->PO_pay));
+			DB( g_print(" -> payee: '%d'\n", txn->kpay) );
+			change = TRUE;
+		}
+
+		if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_cat)) )
+		{
+			if(!(txn->flags & OF_SPLIT))
+			{
+				txn->kcat = ui_cat_comboboxentry_get_key_add_new(GTK_COMBO_BOX(data->PO_cat));
+				DB( g_print(" -> category: '%d'\n", txn->kcat) );
+				change = TRUE;
+			}
+		}
+
+		if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_tags)) )
+		{
+			txt = (gchar *)gtk_entry_get_text(GTK_ENTRY(data->ST_tags));
+			if (txt && *txt)
+			{
+				transaction_tags_parse(txn, txt);
+				DB( g_print(" -> tags: '%s'\n", txt) );
+				change = TRUE;
+			}
+		}
+
+		if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_memo)) )
+		{
+			txt = gtk_entry_get_text(GTK_ENTRY(data->ST_memo));
+			if (txt && *txt)
+			{
+				g_free(txn->wording);
+				txn->wording = g_strdup(txt);
+				change = TRUE;
+			}
+		}
+
+		/* since 5.1 date and amount are no more editable
+			case LST_DSPOPE_DATE:
+				txn->date = gtk_date_entry_get_date(GTK_DATE_ENTRY(widget1));
+				data->do_sort = TRUE;
+				refreshbalance = TRUE;
+				break;
+			case LST_DSPOPE_EXPENSE:
+			case LST_DSPOPE_INCOME:
+			case LST_DSPOPE_AMOUNT:
+				txn->flags &= ~(OF_INCOME);	//delete flag
+				txn->amount = gtk_spin_button_get_value(GTK_SPIN_BUTTON(widget1));
+				if(txn->amount > 0) txn->flags |= OF_INCOME;
+				refreshbalance = TRUE;
+				break;
+		*/
+
+		if( change == TRUE )
+		{
+			txn->flags |= OF_CHANGED;
+			GLOBALS->changes_count++;
+		}
+
+		if( data->has_xfer && txn->paymode == PAYMODE_INTXFER )
+		{
+		Transaction *ltxn;
+
+			ltxn = transaction_xfer_child_strong_get(txn);
+			if(ltxn != NULL) //should never be the case
+			{
+				DB( g_print(" - strong link found, do sync\n") );
+				transaction_xfer_sync_child(txn, ltxn);
+			}
+		}
+
+		list = g_list_previous(list);
+	}
+
+	g_list_foreach(selection, (GFunc)gtk_tree_path_free, NULL);
+	g_list_free(selection);
+
+}
+
+
+static gboolean ui_multipleedit_dialog_destroy( GtkWidget *widget, gpointer user_data )
+{
+struct ui_multipleedit_dialog_data *data;
+
+	data = g_object_get_data(G_OBJECT(widget), "inst_data");
+
+	DB( g_print ("\n[ui-multipleedit] destroy event occurred\n") );
+
+	g_free(data);
+	return FALSE;
+}
+
+
+static GtkWidget *ui_multipleedit_dialog_new(GtkWindow *parent, GtkTreeView *treeview)
+{
+struct ui_multipleedit_dialog_data *data;
+GtkWidget *dialog, *content_area;
+GtkWidget *group_grid, *label, *widget, *toggle;
+gint row;
+
+	DB( g_print ("\n[ui-multipleedit] new\n") );
+
+	data = g_malloc0(sizeof(struct ui_multipleedit_dialog_data));
+
+	dialog = gtk_dialog_new_with_buttons (NULL,
+						GTK_WINDOW (parent),
+						0,
+						_("_Cancel"),
+						GTK_RESPONSE_REJECT,
+						_("_OK"),
+						GTK_RESPONSE_ACCEPT,
+						NULL);
+
+	//g_signal_connect (dialog, "delete_event", G_CALLBACK (register_panel_dispose), (gpointer)data);
+	g_signal_connect (dialog, "destroy", G_CALLBACK (ui_multipleedit_dialog_destroy), (gpointer)data);
+
+	//store our window private data
+	g_object_set_data(G_OBJECT(dialog), "inst_data", (gpointer)data);
+	DB( g_print(" - new window=%p, inst_data=%p\n", dialog, data) );
+
+	data->window = dialog;
+	data->treeview = treeview;
+
+	ui_multipleedit_dialog_init(dialog, NULL);
+
+
+	gtk_window_set_title (GTK_WINDOW (data->window), _("Multiple edit transactions"));
+
+	content_area = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
+
+	group_grid = gtk_grid_new ();
+	gtk_grid_set_row_spacing (GTK_GRID (group_grid), SPACING_SMALL);
+	gtk_grid_set_column_spacing (GTK_GRID (group_grid), SPACING_MEDIUM);
+	gtk_container_set_border_width (GTK_CONTAINER(group_grid), SPACING_MEDIUM);
+	gtk_container_add (GTK_CONTAINER (content_area), group_grid);
+
+	row = -1;
+
+	if( list_txn_column_id_isvisible(GTK_TREE_VIEW(data->treeview), LST_DSPOPE_INFO) == TRUE )
+	{
+		row++;
+		label = make_label_widget(_("Pa_yment:"));
+		data->LB_mode = label;
+		gtk_grid_attach (GTK_GRID (group_grid), label, 0, row, 1, 1);
+		toggle = gtk_check_button_new();
+		data->CM_mode = toggle;
+		gtk_grid_attach (GTK_GRID (group_grid), toggle, 1, row, 1, 1);
+		widget = make_paymode_nointxfer (label);
+		data->NU_mode = widget;
+		gtk_widget_set_hexpand (widget, TRUE);
+		gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
+
+		g_signal_connect (data->CM_mode , "toggled", G_CALLBACK (ui_multipleedit_dialog_update), NULL);
+
+		row++;
+		label = make_label_widget(_("_Info:"));
+		gtk_grid_attach (GTK_GRID (group_grid), label, 0, row, 1, 1);
+		widget = gtk_check_button_new();
+		data->CM_info = widget;
+		gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 1, 1);
+		widget = make_string(label);
+		data->ST_info = widget;
+		gtk_widget_set_hexpand (widget, TRUE);
+		gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
+
+		g_signal_connect (data->CM_info , "toggled", G_CALLBACK (ui_multipleedit_dialog_update), NULL);
+	}
+	
+	if( list_txn_column_id_isvisible(GTK_TREE_VIEW(data->treeview), LST_DSPOPE_PAYEE) == TRUE )
+	{
+		row++;
+		label = make_label_widget(_("_Payee:"));
+		gtk_grid_attach (GTK_GRID (group_grid), label, 0, row, 1, 1);
+		widget = gtk_check_button_new();
+		data->CM_pay = widget;
+		gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 1, 1);
+		widget = ui_pay_comboboxentry_new(label);
+		data->PO_pay = widget;
+		gtk_widget_set_hexpand (widget, TRUE);
+		gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
+
+		g_signal_connect (data->CM_pay  , "toggled", G_CALLBACK (ui_multipleedit_dialog_update), NULL);
+	}
+	
+	if( list_txn_column_id_isvisible(GTK_TREE_VIEW(data->treeview), LST_DSPOPE_CATEGORY) == TRUE )
+	{
+		row++;
+		label = make_label_widget(_("_Category:"));
+		gtk_grid_attach (GTK_GRID (group_grid), label, 0, row, 1, 1);
+		widget = gtk_check_button_new();
+		data->CM_cat = widget;
+		gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 1, 1);
+		widget = ui_cat_comboboxentry_new(label);
+		data->PO_cat = widget;
+		gtk_widget_set_hexpand (widget, TRUE);
+		gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
+
+		g_signal_connect (data->CM_cat  , "toggled", G_CALLBACK (ui_multipleedit_dialog_update), NULL);
+	}
+
+	if( list_txn_column_id_isvisible(GTK_TREE_VIEW(data->treeview), LST_DSPOPE_TAGS) == TRUE )
+	{
+		row++;
+		label = make_label_widget(_("Ta_gs:"));
+		gtk_grid_attach (GTK_GRID (group_grid), label, 0, row, 1, 1);
+		widget = gtk_check_button_new();
+		data->CM_tags = widget;
+		gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 1, 1);
+		widget = make_string(label);
+		data->ST_tags = widget;
+		gtk_widget_set_hexpand (widget, TRUE);
+		gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
+
+		g_signal_connect (data->CM_tags , "toggled", G_CALLBACK (ui_multipleedit_dialog_update), NULL);
+	}
+
+	if( list_txn_column_id_isvisible(GTK_TREE_VIEW(data->treeview), LST_DSPOPE_WORDING) == TRUE )
+	{
+		row++;
+		label = make_label_widget(_("M_emo:"));
+		gtk_grid_attach (GTK_GRID (group_grid), label, 0, row, 1, 1);
+		widget = gtk_check_button_new();
+		data->CM_memo = widget;
+		gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 1, 1);
+		widget = make_memo_entry(label);
+		data->ST_memo = widget;
+		gtk_widget_set_hexpand (widget, TRUE);
+		gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
+
+		g_signal_connect (data->CM_memo , "toggled", G_CALLBACK (ui_multipleedit_dialog_update), NULL);
+	}
+
+
+	ui_multipleedit_dialog_update(dialog, NULL);
+
+	ui_pay_comboboxentry_populate(GTK_COMBO_BOX(data->PO_pay), GLOBALS->h_pay);
+	ui_cat_comboboxentry_populate(GTK_COMBO_BOX(data->PO_cat), GLOBALS->h_cat);
+
+	gtk_widget_show_all (dialog);
+
+
+	if( list_txn_column_id_isvisible(GTK_TREE_VIEW(data->treeview), LST_DSPOPE_INFO) == TRUE )
+	{
+		if(data->has_xfer == TRUE)
+		{
+			hb_widget_visible (data->LB_mode, FALSE);
+			hb_widget_visible (data->CM_mode, FALSE);
+			hb_widget_visible (data->NU_mode, FALSE);
+		}
+	}
+
+	return dialog;
+}
+
+
 /* account action functions -------------------- */
 
 
@@ -108,6 +473,24 @@ struct register_panel_data *data = user_data;
 	register_panel_action(data->window, GINT_TO_POINTER(ACTION_ACCOUNT_EDIT));
 }
 
+static void register_panel_action_multiedit(GtkAction *action, gpointer user_data)
+{
+struct register_panel_data *data = user_data;
+GtkWidget *dialog;
+
+	dialog = ui_multipleedit_dialog_new(GTK_WINDOW(data->window), GTK_TREE_VIEW(data->LV_ope));
+
+	//wait for the user
+	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
+
+	if( result == GTK_RESPONSE_ACCEPT )
+	{
+		ui_multipleedit_dialog_apply (dialog, NULL);
+	}
+
+	gtk_widget_destroy (dialog);
+}
+
 static void register_panel_action_reconcile(GtkAction *action, gpointer user_data)
 {
 struct register_panel_data *data = user_data;
@@ -155,6 +538,104 @@ struct register_panel_data *data = user_data;
 }
 
 
+static void register_panel_action_check_internal_xfer(GtkAction *action, gpointer user_data)
+{
+struct register_panel_data *data = user_data;
+GtkTreeModel *model;
+GtkTreeIter iter;
+GList *badxferlist;
+gboolean valid;
+gint count;
+
+	DB( g_print("check intenal xfer\n\n") );
+
+	badxferlist = NULL;
+	model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_ope));
+	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
+	while (valid)
+	{
+	Transaction *txn;
+
+		gtk_tree_model_get (model, &iter,
+			LST_DSPOPE_DATAS, &txn,
+			-1);
+
+		if( txn->paymode == PAYMODE_INTXFER )
+		{
+			if( transaction_xfer_child_strong_get(txn) == NULL )
+			{
+				DB( g_print(" - invalid xfer: '%s'\n", txn->wording) );
+				
+				//test unrecoverable (kxferacc = 0)
+				if( txn->kxferacc <= 0 )
+				{
+					DB( g_print(" - unrecoverable, revert to normal xfer\n") );
+					txn->flags |= OF_CHANGED;
+					txn->paymode = PAYMODE_XFER;
+					txn->kxfer = 0;
+					txn->kxferacc = 0;
+				}
+				else
+				{
+					badxferlist = g_list_append(badxferlist, txn);
+				}
+			}
+		}
+		
+		valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
+	}
+
+	count = g_list_length (badxferlist);
+	DB( g_print(" - found %d invalid int xfer\n", count) );
+
+	if(count <= 0)
+	{
+		ui_dialog_msg_infoerror(GTK_WINDOW(data->window), GTK_MESSAGE_INFO,
+		_("Check internal transfert result"),
+		_("No inconsistency found !"),
+		NULL);
+	}
+	else
+	{
+	gboolean do_fix;
+	
+		do_fix = ui_dialog_msg_question(
+			GTK_WINDOW(data->window),
+			_("Check internal transfert result"),
+			_("Inconsistency were found: %d\n"
+			  "do you want to review and fix ?"),
+			count
+			);
+
+		if(do_fix == GTK_RESPONSE_YES)
+		{	
+		GList *tmplist = g_list_first(badxferlist);
+
+
+			while (tmplist != NULL)
+			{
+			Transaction *stxn = tmplist->data;
+
+			// (open dialog to select date tolerance in days)
+		// ( with info message)
+		// ( with check/fix button and progress bar)
+
+			//adapt this window
+				//-display the src txn
+				//-enable to display 1 of xxx if more than 1
+
+				transaction_xfer_search_or_add_child(GTK_WINDOW(data->window), stxn);
+
+				tmplist = g_list_next(tmplist);
+			}	
+		}
+	}
+
+	g_list_free (badxferlist);
+
+}
+
+
 static void register_panel_action_exportqif(GtkAction *action, gpointer user_data)
 {
 struct register_panel_data *data = user_data;
@@ -277,8 +758,8 @@ GIOChannel *io;
 			{
 			Transaction *ope;
 			gchar *outstr;
-			GDate *date;
-			gchar datebuf[256];
+			
+			gchar datebuf[16];
 			gchar *info, *payeename, *categoryname;
 			Payee *payee;
 			Category *category;
@@ -289,26 +770,7 @@ GIOChannel *io;
 						LST_DSPOPE_DATAS, &ope,
 						-1);
 
-			//date
-				date = g_date_new_julian (ope->date);
-				if( PREFS->dtex_datefmt == PRF_DATEFMT_MDY )
-				{
-					g_sprintf(datebuf, "%02d/%02d/%04d",
-						g_date_get_month(date),
-						g_date_get_day(date),
-						g_date_get_year(date)
-						);
-				}
-				else
-				{
-					g_sprintf(datebuf, "%02d/%02d/%04d",
-						g_date_get_day(date),
-						g_date_get_month(date),
-						g_date_get_year(date)
-						);
-				}	
-					
-				g_date_free(date);
+				hb_sprint_date(datebuf, ope->date);
 
 				info = ope->info;
 				if(info == NULL) info = "";
@@ -821,32 +1283,6 @@ Transaction *txn;
 }
 
 
-Transaction *get_active_transaction(GtkTreeView *treeview)
-{
-GtkTreeModel *model;
-GList *list;
-Transaction *ope;
-
-	ope = NULL;
-
-	model = gtk_tree_view_get_model(treeview);
-	list = gtk_tree_selection_get_selected_rows(gtk_tree_view_get_selection(treeview), &model);
-
-	if(list != NULL)
-	{
-	GtkTreeIter iter;
-
-		gtk_tree_model_get_iter(model, &iter, list->data);
-		gtk_tree_model_get(model, &iter, LST_DSPOPE_DATAS, &ope, -1);
-	}
-
-	g_list_foreach(list, (GFunc)gtk_tree_path_free, NULL);
-	g_list_free(list);
-
-	return ope;
-}
-
-
 static void delete_active_transaction(GtkTreeView *treeview)
 {
 GtkTreeModel *model;
@@ -908,7 +1344,7 @@ gboolean result;
 			else
 			{
 				DB( g_print("(transaction) inherit multiple\n") );
-				src_txn = da_transaction_clone(get_active_transaction(GTK_TREE_VIEW(data->LV_ope)));
+				src_txn = da_transaction_clone(list_txn_get_active_transaction(GTK_TREE_VIEW(data->LV_ope)));
 				//#1432204
 				src_txn->status = TXN_STATUS_NONE;
 				type = TRANSACTION_EDIT_INHERIT;
@@ -957,108 +1393,43 @@ gboolean result;
 
 		case ACTION_ACCOUNT_EDIT:
 			{
-		Transaction *old_txn;
-		GtkWidget *dialog;
+		Transaction *active_txn;
 
-			old_txn = get_active_transaction(GTK_TREE_VIEW(data->LV_ope));
-			if(old_txn)
+			active_txn = list_txn_get_active_transaction(GTK_TREE_VIEW(data->LV_ope));
+					
+			if(active_txn)
 			{
-				dialog = create_deftransaction_window(GTK_WINDOW(data->window), TRANSACTION_EDIT_MODIFY, FALSE);
+			Transaction *old_txn, *new_txn;
 
-				data->cur_ope = da_transaction_clone (old_txn); // to keep old datas, just in case
-				deftransaction_set_transaction(dialog, data->cur_ope);
+				old_txn = da_transaction_clone (active_txn);
+				new_txn = active_txn;
 				
-				result = gtk_dialog_run (GTK_DIALOG (dialog));
+				result = deftransaction_external_edit(GTK_WINDOW(data->window), old_txn, new_txn);
+
 				if(result == GTK_RESPONSE_ACCEPT)
 				{
-					deftransaction_get(dialog, NULL);
+					//#1270687: sort if date changed
+					if(old_txn->date != new_txn->date)
+						data->do_sort = TRUE;
 
-					account_balances_sub(old_txn);
-					account_balances_add(data->cur_ope);
-
-					// different accoutn : delete from the display
-					if( data->cur_ope->kacc != data->accnum )
+					// different account : delete from the display
+					if( new_txn->kacc != data->accnum )
 					{
 						delete_active_transaction(GTK_TREE_VIEW(data->LV_ope));
 					}
 
-					if( data->cur_ope->paymode == PAYMODE_INTXFER )
-					{
-						//nota: if kxfer is 0, the user may have just changed the paymode to xfer
-						DB( g_print(" - kxfer = %d\n", data->cur_ope->kxfer) );
-
-						if(data->cur_ope->kxfer > 0)	//1) search a strong linked child
-						{
-						Transaction *ltxn;
-
-							DB( g_print(" - old_txn: kacc=%d kxferacc=%d\n", old_txn->kacc, old_txn->kxferacc) );
-							
-							ltxn = transaction_strong_get_child_transfer(old_txn);
-							if(ltxn != NULL) //should never be the case
-							{
-								DB( g_print(" - strong link found, do sync\n") );
-								transaction_xfer_sync_child(data->cur_ope, ltxn);
-							}
-							else
-							{
-								DB( g_print(" - no, somethin' went wrong here...\n") );
-							}
-						}
-						else
-						{
-							//2) any standard transaction that match ?
-							transaction_xfer_search_or_add_child(data->cur_ope, data->LV_ope);
-						}
-					}
-
-					//#1250061 : manage ability to break an internal xfer
-					if(old_txn->paymode == PAYMODE_INTXFER && data->cur_ope->paymode != PAYMODE_INTXFER)
-					{
-					GtkWidget *p_dialog;
-						
-						DB( g_print(" - should break internal xfer\n") );
-
-						p_dialog = gtk_message_dialog_new
-						(
-							GTK_WINDOW(data->window),
-							GTK_DIALOG_MODAL,
-							GTK_MESSAGE_WARNING,
-							GTK_BUTTONS_YES_NO,
-							_("Do you want to break the internal transfer ?\n\n"
-							  "Proceeding will delete the target transaction.")
-						);
-
-						result = gtk_dialog_run( GTK_DIALOG( p_dialog ) );
-						gtk_widget_destroy( p_dialog );
-
-						if(result == GTK_RESPONSE_YES)
-						{
-							transaction_xfer_remove_child(data->cur_ope);
-						}
-						else	//force paymode to internal xfer
-						{
-							data->cur_ope->paymode = PAYMODE_INTXFER;
-						}
-					}
 					
-					//#1270687: sort if date changed
-					if(old_txn->date != data->cur_ope->date)
-						data->do_sort = TRUE;
-					
-					da_transaction_copy(data->cur_ope, old_txn);
+					//da_transaction_copy(new_txn, old_txn);
 
 					register_panel_update(widget, GINT_TO_POINTER(UF_BALANCE));
 
 					data->acc->flags |= AF_CHANGED;
 					GLOBALS->changes_count++;
-
 				}
 
-				da_transaction_free (data->cur_ope);
 
+				da_transaction_free (old_txn);
 			
-				deftransaction_dispose(dialog, NULL);
-				gtk_widget_destroy (dialog);
 			}
 
 		}
@@ -1361,27 +1732,26 @@ gint count = 0;
 
 		// multiple: disable inherit, edit
 		sensitive = (count != 1 ) ? FALSE : TRUE;
+		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/MenuBar/TxnMenu/Inherit"), sensitive);
+		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/MenuBar/TxnMenu/Edit"), sensitive);
 		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/TxnBar/Inherit"), sensitive);
 		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/TxnBar/Edit"), sensitive);
-		
-		sensitive = (count > 0 ) ? TRUE : FALSE;
+
+		// single: disable multiedit
+		sensitive = (count <= 1 ) ? FALSE : TRUE;
+		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/MenuBar/TxnMenu/MultiEdit"), sensitive);
+		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/TxnBar/MultiEdit"), sensitive);
+
 		// no selection: disable reconcile, delete
-		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/MenuBar/TxnMenu/TxnStatusMenu/None"), sensitive);
-		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/MenuBar/TxnMenu/TxnStatusMenu/Cleared"), sensitive);
-		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/MenuBar/TxnMenu/TxnStatusMenu/Reconciled"), sensitive);
+		sensitive = (count > 0 ) ? TRUE : FALSE;
+		gtk_widget_set_sensitive (gtk_ui_manager_get_widget(data->ui, "/MenuBar/TxnMenu/TxnStatusMenu"), sensitive);
 		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/MenuBar/TxnMenu/Delete"), sensitive);
 		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/MenuBar/TxnMenu/Template"), sensitive);
-
 		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/TxnBar/Delete"), sensitive);
 		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/TxnBar/Cleared"), sensitive);
 		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/TxnBar/Reconciled"), sensitive);
 		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/TxnBar/Template"), sensitive);
 
-		// multiple: disable inherit, edit
-		sensitive = (count != 1 ) ? FALSE : TRUE;
-		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/MenuBar/TxnMenu/Inherit"), sensitive);
-		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->ui, "/MenuBar/TxnMenu/Edit"), sensitive);
-
 		// euro convert
 		sensitive = PREFS->euro_active;
 		gtk_action_set_visible(gtk_ui_manager_get_action(data->ui, "/MenuBar/ToolsMenu/ConvToEuro"), sensitive);
@@ -1416,11 +1786,6 @@ gint count = 0;
 
 		register_panel_balance_refresh(widget);
 		
-		/*
-		hb_label_set_colvaluecurr(GTK_LABEL(data->TX_balance[0]), data->acc->bal_bank, data->acc->kcur);
-		hb_label_set_colvaluecurr(GTK_LABEL(data->TX_balance[1]), data->acc->bal_today, data->acc->kcur);
-		hb_label_set_colvaluecurr(GTK_LABEL(data->TX_balance[2]), data->acc->bal_future, data->acc->kcur);
-		*/
 		hb_label_set_colvalue(GTK_LABEL(data->TX_balance[0]), data->acc->bal_bank, GLOBALS->minor);
 		hb_label_set_colvalue(GTK_LABEL(data->TX_balance[1]), data->acc->bal_today, GLOBALS->minor);
 		hb_label_set_colvalue(GTK_LABEL(data->TX_balance[2]), data->acc->bal_future, GLOBALS->minor);
@@ -1473,11 +1838,6 @@ gint count = 0;
 
 		DB( g_print(" %f - %f = %f\n", opeinc, opeexp, opeinc + opeexp) );
 
-		/*
-		hb_strfmon(buf1, 64-1, opeinc, data->acc->kcur);
-		hb_strfmon(buf2, 64-1, -opeexp, data->acc->kcur);
-		hb_strfmon(buf3, 64-1, opeinc + opeexp, data->acc->kcur);
-		*/
 		mystrfmon(buf1, 64-1, opeinc, GLOBALS->minor);
 		mystrfmon(buf2, 64-1, -opeexp, GLOBALS->minor);
 		mystrfmon(buf3, 64-1, opeinc + opeexp, GLOBALS->minor);
@@ -1508,10 +1868,7 @@ struct register_panel_data *data;
 GtkTreeModel *model;
 GtkTreeIter iter;
 gint col_id, count;
-GList *selection, *list;
 Transaction *ope;
-gchar *tagstr;
-gboolean refreshbalance;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(GTK_WIDGET(treeview), GTK_TYPE_WINDOW)), "inst_data");
 
@@ -1526,7 +1883,7 @@ gboolean refreshbalance;
 	gtk_tree_model_get(model, &iter, LST_DSPOPE_DATAS, &ope, -1);
 
 
-		DB( g_print ("%d rows been double-clicked on column=%d! ope=%s\n", count, col_id, ope->wording) );
+	DB( g_print ("%d rows been double-clicked on column=%d! ope=%s\n", count, col_id, ope->wording) );
 
 	if( count == 1)
 	{
@@ -1535,179 +1892,7 @@ gboolean refreshbalance;
 	else
 	if(col_id >= LST_DSPOPE_DATE && col_id != LST_DSPOPE_BALANCE)
 	{
-	GtkWidget *parentwindow, *dialog, *mainbox, *widget1, *widget2, *content;
-
-		parentwindow = gtk_widget_get_ancestor(GTK_WIDGET(treeview), GTK_TYPE_WINDOW);
-
-		dialog = gtk_dialog_new_with_buttons (NULL,
-							GTK_WINDOW (parentwindow),
-							0,
-							_("_Cancel"),
-							GTK_RESPONSE_REJECT,
-							_("_OK"),
-							GTK_RESPONSE_ACCEPT,
-							NULL);
-
-		gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_MOUSE);
-		gint w;
-		w = gtk_tree_view_column_get_width(GTK_TREE_VIEW_COLUMN(col));
-		gtk_window_set_default_size (GTK_WINDOW(dialog), w + 40, 0);
-
-		content = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
-
-		mainbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-		gtk_container_set_border_width (GTK_CONTAINER (mainbox), SPACING_SMALL);
-		gtk_box_pack_start (GTK_BOX (content), mainbox, FALSE, FALSE, 0);
-
-		widget1 = widget2 = NULL;
-
-		switch( col_id )
-		{
-			case LST_DSPOPE_DATE:
-				gtk_window_set_title (GTK_WINDOW (dialog), _("Modify date..."));
-				widget1 = gtk_date_entry_new();
-				gtk_date_entry_set_date(GTK_DATE_ENTRY(widget1), (guint)ope->date);
-				break;
-			case LST_DSPOPE_INFO:
-				gtk_window_set_title (GTK_WINDOW (dialog), _("Modify info..."));
-				widget1 = make_paymode(NULL);
-				widget2 = make_string(NULL);
-				gtk_combo_box_set_active(GTK_COMBO_BOX(widget1), ope->paymode);
-				gtk_entry_set_text(GTK_ENTRY(widget2), (ope->info != NULL) ? ope->info : "");
-				break;
-			case LST_DSPOPE_PAYEE:
-				gtk_window_set_title (GTK_WINDOW (dialog), _("Modify payee..."));
-				widget1 = ui_pay_comboboxentry_new(NULL);
-				ui_pay_comboboxentry_populate(GTK_COMBO_BOX(widget1), GLOBALS->h_pay);
-				ui_pay_comboboxentry_set_active(GTK_COMBO_BOX(widget1), ope->kpay);
-				break;
-			case LST_DSPOPE_WORDING:
-				gtk_window_set_title (GTK_WINDOW (dialog), _("Modify description..."));
-				widget1 = make_string(NULL);
-				gtk_entry_set_text(GTK_ENTRY(widget1), (ope->wording != NULL) ? ope->wording : "");
-				break;
-			case LST_DSPOPE_EXPENSE:
-			case LST_DSPOPE_INCOME:
-			case LST_DSPOPE_AMOUNT:
-				gtk_window_set_title (GTK_WINDOW (dialog), _("Modify amount..."));
-				widget1 = make_amount(NULL);
-				gtk_spin_button_set_value(GTK_SPIN_BUTTON(widget1), ope->amount);
-				break;
-			case LST_DSPOPE_CATEGORY:
-				gtk_window_set_title (GTK_WINDOW (dialog), _("Modify category..."));
-				widget1 = ui_cat_comboboxentry_new(FALSE);
-				ui_cat_comboboxentry_populate(GTK_COMBO_BOX(widget1), GLOBALS->h_cat);
-				ui_cat_comboboxentry_set_active(GTK_COMBO_BOX(widget1), ope->kcat);
-				break;
-			case LST_DSPOPE_TAGS:
-				gtk_window_set_title (GTK_WINDOW (dialog), _("Modify tags..."));
-				widget1 = make_string(NULL);
-				tagstr = transaction_tags_tostring(ope);
-				gtk_entry_set_text(GTK_ENTRY(widget1), (tagstr != NULL) ? tagstr : "");
-				g_free(tagstr);
-
-				break;
-		}
-
-		if(widget1 != NULL) gtk_box_pack_start (GTK_BOX (mainbox), widget1, TRUE, TRUE, 0);
-		if(widget2 != NULL) gtk_box_pack_start (GTK_BOX (mainbox), widget2, TRUE, TRUE, 0);
-
-		gtk_widget_show_all(mainbox);
-
-		//wait for the user
-		gint result = gtk_dialog_run (GTK_DIALOG (dialog));
-
-		if(result == GTK_RESPONSE_ACCEPT)
-		{
-			selection = gtk_tree_selection_get_selected_rows(gtk_tree_view_get_selection(treeview), &model);
-
-			refreshbalance = FALSE;
-			
-			list = g_list_first(selection);
-			while(list != NULL)
-			{
-			GtkTreeIter iter;
-			const gchar *txt;
-
-				gtk_tree_model_get_iter(model, &iter, list->data);
-				gtk_tree_model_get(model, &iter, LST_DSPOPE_DATAS, &ope, -1);
-
-				DB( g_print(" modifying %s %.2f\n", ope->wording, ope->amount) );
-
-				switch( col_id )
-				{
-					case LST_DSPOPE_DATE:
-						ope->date = gtk_date_entry_get_date(GTK_DATE_ENTRY(widget1));
-						data->do_sort = TRUE;
-						refreshbalance = TRUE;
-						break;
-					case LST_DSPOPE_INFO:
-						ope->paymode = gtk_combo_box_get_active(GTK_COMBO_BOX(widget1));
-						txt = gtk_entry_get_text(GTK_ENTRY(widget2));
-						if (txt && *txt)
-						{
-							g_free(ope->info);
-							ope->info = g_strdup(txt);
-						}
-						break;
-					case LST_DSPOPE_PAYEE:
-						ope->kpay = ui_pay_comboboxentry_get_key_add_new(GTK_COMBO_BOX(widget1));
-						DB( g_print(" -> payee: '%d'\n", ope->kpay) );
-						break;
-					case LST_DSPOPE_WORDING:
-						txt = gtk_entry_get_text(GTK_ENTRY(widget1));
-						if (txt && *txt)
-						{
-							g_free(ope->wording);
-							ope->wording = g_strdup(txt);
-						}
-						break;
-					case LST_DSPOPE_EXPENSE:
-					case LST_DSPOPE_INCOME:
-					case LST_DSPOPE_AMOUNT:
-						ope->flags &= ~(OF_INCOME);	//delete flag
-						ope->amount = gtk_spin_button_get_value(GTK_SPIN_BUTTON(widget1));
-						if(ope->amount > 0) ope->flags |= OF_INCOME;
-						refreshbalance = TRUE;
-						break;
-					case LST_DSPOPE_CATEGORY:
-						if(!(ope->flags & OF_SPLIT))
-						{
-							ope->kcat = ui_cat_comboboxentry_get_key_add_new(GTK_COMBO_BOX(widget1));
-							//bad .... ope->category = gtk_combo_box_get_active(GTK_COMBO_BOX(widget1));
-							DB( g_print(" -> category: '%d'\n", ope->kcat) );
-						}
-						break;
-					case LST_DSPOPE_TAGS:
-						txt = (gchar *)gtk_entry_get_text(GTK_ENTRY(widget1));
-						if (txt && *txt)
-						{
-							DB( g_print(" -> tags: '%s'\n", txt) );
-
-							transaction_tags_parse(ope, txt);
-						}
-
-						break;
-
-				}
-
-				ope->flags |= OF_CHANGED;
-				GLOBALS->changes_count++;
-
-				list = g_list_next(list);
-			}
-
-			if(refreshbalance)
-				register_panel_update(GTK_WIDGET(treeview), GINT_TO_POINTER(UF_BALANCE));
-
-
-			g_list_foreach(selection, (GFunc)gtk_tree_path_free, NULL);
-			g_list_free(selection);
-		}
-
-		// cleanup and destroy
-		gtk_widget_destroy (dialog);
-
+		register_panel_action_multiedit(NULL, data);
 	}
 }
 
@@ -1920,83 +2105,83 @@ static GtkActionEntry entries[] = {
 
 	{ "Add"				, ICONNAME_HB_OPE_ADD	 , N_("_Add..."), NULL,		N_("Add a new transaction"), G_CALLBACK (register_panel_action_add) },
 	{ "Inherit"			, ICONNAME_HB_OPE_HERIT	 , N_("_Inherit..."), NULL, N_("Inherit from the active transaction"), G_CALLBACK (register_panel_action_inherit) },
-	{ "Edit"			, ICONNAME_HB_OPE_EDIT	 , N_("_Edit..."), NULL, N_("Edit the active transaction"),	G_CALLBACK (register_panel_action_edit) },
+	{ "Edit"			, ICONNAME_HB_OPE_EDIT	 , N_("_Edit..."), NULL, N_("Edit the active transaction"),	G_CALLBACK (register_panel_action_edit) },	
+
 	{ "None"	    	, NULL                   , N_("_None"), "<control>N",		N_("Toggle none for selected transaction(s)"), G_CALLBACK (register_panel_action_none) },
 	{ "Cleared"	    	, ICONNAME_HB_OPE_CLEARED, N_("_Cleared"), "<control>C",		N_("Toggle cleared for selected transaction(s)"), G_CALLBACK (register_panel_action_clear) },
 	{ "Reconciled"		, ICONNAME_HB_OPE_RECONCILED, N_("_Reconciled"), "<control>R",		N_("Toggle reconciled for selected transaction(s)"), G_CALLBACK (register_panel_action_reconcile) },
-	{ "Delete"			, ICONNAME_HB_OPE_DELETE , N_("_Delete..."), NULL,		N_("Delete selected transaction(s)"), G_CALLBACK (register_panel_action_remove) },
+
+	{ "MultiEdit"	, ICONNAME_HB_OPE_MULTIEDIT , N_("_Multiple Edit..."), NULL, N_("Edit multiple transaction"),	G_CALLBACK (register_panel_action_multiedit) },
 	{ "Template"    	, ICONNAME_CONVERT       , N_("Create template..."), NULL,		N_("Create template"), G_CALLBACK (register_panel_action_createtemplate) },
+	{ "Delete"			, ICONNAME_HB_OPE_DELETE , N_("_Delete..."), NULL,		N_("Delete selected transaction(s)"), G_CALLBACK (register_panel_action_remove) },
 
 	{ "Assign"			, ICONNAME_HB_ASSIGN_RUN , N_("Auto. Assignments"), NULL,		N_("Run auto assignments"), G_CALLBACK (register_panel_action_assign) },
-	{ "ExportQIF"		, ICONNAME_HB_FILE_EXPORT, N_("Export QIF..."), NULL,		N_("Export as QIF"), G_CALLBACK (register_panel_action_exportqif) },
-	{ "ExportCSV"		, ICONNAME_HB_FILE_EXPORT, N_("Export CSV..."), NULL,		N_("Export as CSV"), G_CALLBACK (register_panel_action_exportcsv) },
+	{ "ExportQIF"		, NULL						, N_("Export QIF..."), NULL,		N_("Export as QIF"), G_CALLBACK (register_panel_action_exportqif) },
+	{ "ExportCSV"		, NULL						, N_("Export CSV..."), NULL,		N_("Export as CSV"), G_CALLBACK (register_panel_action_exportcsv) },
+
+	{ "ChkIntXfer"  , NULL                      , N_("Check internal xfer..."), NULL,	NULL, G_CALLBACK (register_panel_action_check_internal_xfer) },
 
 };
 static guint n_entries = G_N_ELEMENTS (entries);
 
 static const gchar *ui_info =
 "<ui>"
-"	<menubar name='MenuBar'>"
+"<menubar name='MenuBar'>"
 
-"		<menu action='AccountMenu'>"
-"			<menuitem action='Close'/>"
-"		</menu>"
+"	<menu action='AccountMenu'>"
+"		<menuitem action='ExportQIF'/>"
+"		<menuitem action='ExportCSV'/>"
+"			<separator/>"
+"		<menuitem action='Close'/>"
+"	</menu>"
 
-"		<menu action='TxnMenu'>"
-"			<menuitem action='Add'/>"
-"			<menuitem action='Inherit'/>"
-"			<menuitem action='Edit'/>"
-"			<menuitem action='Delete'/>"
-"				<separator/>"
-"		   <menu action='TxnStatusMenu'>"
-"				<menuitem action='None'/>"
-"				<menuitem action='Cleared'/>"
-"				<menuitem action='Reconciled'/>"
-"		   </menu>"
+"	<menu action='TxnMenu'>"
+"		<menuitem action='Add'/>"
+"		<menuitem action='Inherit'/>"
+"		<menuitem action='Edit'/>"
+"			<separator/>"
+"	   <menu action='TxnStatusMenu'>"
+"			<menuitem action='None'/>"
+"			<menuitem action='Cleared'/>"
+"			<menuitem action='Reconciled'/>"
+"	   </menu>"
+"		<menuitem action='MultiEdit'/>"
+"		<menuitem action='Template'/>"
+"		<menuitem action='Delete'/>"
+"	</menu>"
 
-"				<separator/>"
-"			<menuitem action='Template'/>"
-"		</menu>"
-
-"		<menu action='ActionsMenu'>"
-"			<menuitem action='Assign'/>"
-"				<separator/>"
-"			<menuitem action='ExportQIF'/>"
-"			<menuitem action='ExportCSV'/>"
-"		</menu>"
+"	<menu action='ActionsMenu'>"
+"		<menuitem action='Assign'/>"
+"			<separator/>"
+"		<menuitem action='ChkIntXfer'/>"
+"	</menu>"
 
 "		<menu action='ToolsMenu'>"
 "			<menuitem action='Filter'/>"
 "				<separator/>"
 "			<menuitem action='ConvToEuro'/>"
 "		</menu>"
-"	</menubar>"
+"</menubar>"
 
-"	<toolbar name='TxnBar'>"
-"		<toolitem action='Cleared'/>"
-"		<toolitem action='Reconciled'/>"
-"			<separator/>"
-"		<toolitem action='Add'/>"
-"		<toolitem action='Inherit'/>"
-"		<toolitem action='Edit'/>"
-"			<separator/>"
-"		<toolitem action='Template'/>"
-"		<toolitem action='Delete'/>"
-"	</toolbar>"
-"	<toolbar name='ToolBar'>"
-"		<toolitem action='Filter'/>"
-"		<toolitem action='Assign'/>"
-"			<separator/>"
-"		<toolitem action='ExportQIF'/>"
-"		<toolitem action='ExportCSV'/>"
-"	</toolbar>"
+"<toolbar name='TxnBar'>"
+"	<toolitem action='Add'/>"
+"	<toolitem action='Inherit'/>"
+"	<toolitem action='Edit'/>"
+"		<separator/>"
+"	<toolitem action='Cleared'/>"
+"	<toolitem action='Reconciled'/>"
+"		<separator/>"
+"	<toolitem action='MultiEdit'/>"
+"	<toolitem action='Template'/>"
+"	<toolitem action='Delete'/>"
+"</toolbar>"
+"<toolbar name='ToolBar'>"
+"	<toolitem action='Filter'/>"
+"	<toolitem action='Assign'/>"
+"</toolbar>"
 "</ui>";
 
 
-
-
-
-
 GtkWidget *register_panel_window_new(guint32 accnum, Account *acc)
 {
 struct register_panel_data *data;
@@ -2169,17 +2354,17 @@ GError *error = NULL;
 	gtk_box_pack_start (GTK_BOX (mainbox), table, FALSE, FALSE, 0);
 
 	
-	label = make_label(_("_Range:"), 1.0, 0.5);
+	label = make_label_widget(_("_Range:"));
 	gtk_grid_attach (GTK_GRID(table), label, 0, 0, 1, 1);
 	data->CY_range = make_daterange(label, TRUE);
 	gtk_grid_attach (GTK_GRID(table), data->CY_range, 1, 0, 1, 1);
 
-	label = make_label(_("_Type:"), 1.0, 0.5);
+	label = make_label_widget(_("_Type:"));
 	gtk_grid_attach (GTK_GRID(table), label, 2, 0, 1, 1);
 	data->CY_type = make_cycle(label, CYA_FLT_TYPE);
 	gtk_grid_attach (GTK_GRID(table), data->CY_type, 3, 0, 1, 1);
 
-	label = make_label(_("_Status:"), 1.0, 0.5);
+	label = make_label_widget(_("_Status:"));
 	gtk_grid_attach (GTK_GRID(table), label, 4, 0, 1, 1);
 	data->CY_status = make_cycle(label, CYA_FLT_STATUS);
 	gtk_grid_attach (GTK_GRID(table), data->CY_status, 5, 0, 1, 1);
@@ -2200,12 +2385,12 @@ GError *error = NULL;
 	gtk_grid_attach (GTK_GRID(table), label, 10, 0, 1, 1);
 
 	/*
-	label = make_label(_("_Month:"), 1.0, 0.5);
+	label = make_label_widget(_("_Month:"));
 		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	data->CY_month = make_cycle(label, CYA_SELECT);
 		gtk_box_pack_start (GTK_BOX (hbox), data->CY_month, FALSE, FALSE, 0);
 
-	label = make_label(_("_Year:"), 1.0, 0.5);
+	label = make_label_widget(_("_Year:"),);
 		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	data->NB_year = make_year(label);
 		gtk_box_pack_start (GTK_BOX (hbox), data->NB_year, FALSE, FALSE, 0);
@@ -2239,7 +2424,6 @@ GError *error = NULL;
 	//gtk_style_context_add_class (gtk_widget_get_style_context (widget), GTK_STYLE_CLASS_INLINE_TOOLBAR);
 	gtk_widget_set_hexpand (widget, TRUE);
 	gtk_grid_attach (GTK_GRID(table), widget, 2, 0, 1, 1);
-	
 
     #ifdef G_OS_WIN32
     if(PREFS->toolbar_style == 0)
