@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2015 Maxime DOYEN
+ *  Copyright (C) 1995-2016 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -969,6 +969,44 @@ csvend:
 }
 
 
+gchar *hb_sprint_date(gchar *outstr, guint32 julian)
+{
+GDate date;
+
+	g_date_clear(&date, 1);
+	g_date_set_julian (&date, julian);
+	switch(PREFS->dtex_datefmt)
+	{
+		case PRF_DATEFMT_MDY:
+		{
+			g_sprintf(outstr, "%02d/%02d/%04d",
+				g_date_get_month(&date),
+				g_date_get_day(&date),
+				g_date_get_year(&date)
+				);
+		}
+		break;
+		case PRF_DATEFMT_DMY:
+		{
+			g_sprintf(outstr, "%02d/%02d/%04d",
+				g_date_get_day(&date),
+				g_date_get_month(&date),
+				g_date_get_year(&date)
+				);
+		}	
+		default:
+			g_sprintf(outstr, "%04d/%02d/%02d",
+				g_date_get_year(&date),
+				g_date_get_month(&date),
+				g_date_get_day(&date)
+				);
+			break;
+	}
+	return outstr;
+}
+
+
+//used only in DB() macro !!
 void hb_print_date(guint32 jdate, gchar *label)
 {
 gchar buffer1[128];
