@@ -491,7 +491,7 @@ GList *matchlist;
 
 	matchlist = transaction_xfer_child_might_list_get(ope);
 
-	DB( g_print(" - found result is %d, switching\n", count) );
+	DB( g_print(" - found result is %d, switching\n", g_list_length(matchlist)) );
 
 	Transaction *child;
 
