@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal ruleing for everyone.
- *  Copyright (C) 1995-2015 Maxime DOYEN
+ *  Copyright (C) 1995-2016 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -704,7 +704,7 @@ gint w, h, row;
 	gtk_grid_set_row_spacing (GTK_GRID (table), SPACING_SMALL);
 	gtk_grid_set_column_spacing (GTK_GRID (table), SPACING_MEDIUM);
 	//gtk_box_pack_start (GTK_BOX (mainbox), table, FALSE, FALSE, 0);
-	gtk_widget_set_margin_end(table, SPACING_SMALL);
+	gtk_widget_set_margin_right(table, SPACING_SMALL);
 	gtk_paned_pack1 (GTK_PANED(hpaned), table, FALSE, FALSE);
 
 	row = 0;
@@ -733,7 +733,7 @@ gint w, h, row;
 	gtk_grid_set_row_spacing (GTK_GRID (content_grid), SPACING_LARGE);
 	gtk_orientable_set_orientation(GTK_ORIENTABLE(content_grid), GTK_ORIENTATION_VERTICAL);
 	//gtk_container_set_border_width (GTK_CONTAINER(content_grid), SPACING_MEDIUM);
-	gtk_widget_set_margin_start(content_grid, SPACING_SMALL);
+	gtk_widget_set_margin_left(content_grid, SPACING_SMALL);
 	gtk_paned_pack2 (GTK_PANED(hpaned), content_grid, FALSE, FALSE);
 
 	// group :: Condition
