@@ -1,5 +1,5 @@
 /*	HomeBank -- Free, easy, personal accounting for everyone.
- *	Copyright (C) 1995-2015 Maxime DOYEN
+ *	Copyright (C) 1995-2016 Maxime DOYEN
  *
  *	This file is part of HomeBank.
  *
@@ -2079,8 +2079,7 @@ GtkWidget *ui_import_assistant_new (gint filetype)
 {
 struct import_data *data;
 GtkWidget *assistant;
-GdkScreen *screen;
-gint width, height;
+gint w, h;
 gint pos;
 
 	data = g_malloc0(sizeof(struct import_data));
@@ -2099,27 +2098,10 @@ gint pos;
 	gtk_window_set_modal(GTK_WINDOW (assistant), TRUE);
 	gtk_window_set_transient_for(GTK_WINDOW(assistant), GTK_WINDOW(GLOBALS->mainwindow));
 
-#if FORCE_SIZE == 1
-	screen = gtk_window_get_screen(GTK_WINDOW (assistant));
-	// fix #379372 : manage multiple monitor case
-	if( gdk_screen_get_n_monitors(screen) > 1 )
-	{
-	GdkRectangle rect;
+	//set a nice dialog size
+	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
+	gtk_window_set_default_size (GTK_WINDOW(assistant), w*0.8, h*0.8);
 
-		gdk_screen_get_monitor_geometry(screen, 1, &rect);
-		width = rect.width;
-		height = rect.height;
-	}
-	else
-	{
-		width  = gdk_screen_get_width(screen);
-		height = gdk_screen_get_height(screen);
-	}
-
-	//gtk_window_resize(GTK_WINDOW(assistant), (height - 128) * PHI, height - 128);
-	gtk_window_resize(GTK_WINDOW(assistant), width/PHI, height/PHI);
-	gtk_window_set_position (GTK_WINDOW (assistant), GTK_WIN_POS_CENTER);
-#endif
 
 
 	pos = 0;
