@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2015 Maxime DOYEN
+ *  Copyright (C) 1995-2016 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -747,7 +747,7 @@ GtkWidget *container, *scrollwin, *hbox, *vbox, *label, *widget;
 	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, SPACING_SMALL);
 	gtk_box_pack_start (GTK_BOX (container), hbox, FALSE, FALSE, 0);
 
-	label = make_label(_("_Option:"), 1.0, 0.5);
+	label = make_label_widget(_("_Option:"));
 	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
 	data->CY_option[FILTER_CATEGORY] = make_nainex(label);
 	gtk_box_pack_start (GTK_BOX (hbox), data->CY_option[FILTER_CATEGORY], TRUE, TRUE, 0);
@@ -796,7 +796,7 @@ GtkWidget *container, *scrollwin, *hbox, *vbox, *label, *widget;
 	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, SPACING_SMALL);
 	gtk_box_pack_start (GTK_BOX (container), hbox, FALSE, FALSE, 0);
 
-	label = make_label(_("_Option:"), 1.0, 0.5);
+	label = make_label_widget(_("_Option:"));
 	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
 	data->CY_option[FILTER_PAYEE] = make_nainex(label);
 	gtk_box_pack_start (GTK_BOX (hbox), data->CY_option[FILTER_PAYEE], TRUE, TRUE, 0);
@@ -845,7 +845,7 @@ GtkWidget *container, *scrollwin, *hbox, *vbox, *label, *widget;
 	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, SPACING_SMALL);
 	gtk_box_pack_start (GTK_BOX (container), hbox, FALSE, FALSE, 0);
 
-	label = make_label(_("_Option:"), 1.0, 0.5);
+	label = make_label_widget(_("_Option:"));
 	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
 	data->CY_option[FILTER_ACCOUNT] = make_nainex(label);
 	gtk_box_pack_start (GTK_BOX (hbox), data->CY_option[FILTER_ACCOUNT], TRUE, TRUE, 0);
@@ -1309,10 +1309,10 @@ GtkWidget *container, *part;
 /*
 **
 */
-gint ui_flt_manage_dialog_new(Filter *filter, gboolean show_account)
+gint ui_flt_manage_dialog_new(GtkWidget *widget, Filter *filter, gboolean show_account)
 {
 struct ui_flt_manage_data data;
-GtkWidget *window, *content, *mainbox, *notebook, *label, *page;
+GtkWidget *parentwindow, *window, *content, *mainbox, *notebook, *label, *page;
 
 	//data = g_malloc0(sizeof(struct ui_flt_manage_data));
 	//if(!data) return NULL;
@@ -1320,9 +1320,10 @@ GtkWidget *window, *content, *mainbox, *notebook, *label, *page;
 
 	data.filter = filter;
 
+	parentwindow = gtk_widget_get_ancestor(GTK_WIDGET(widget), GTK_TYPE_WINDOW);
+
 	window = gtk_dialog_new_with_buttons (_("Edit Filter"),
-					    //GTK_WINDOW (do_widget),
-					    NULL,
+					    GTK_WINDOW (parentwindow),
 					    0,
 					    _("_Reset"),
 					    55,
