@@ -71,7 +71,7 @@ static void deftransaction_update(GtkWidget *widget, gpointer user_data)
 struct deftransaction_data *data;
 gboolean sensitive;
 
-	DB( g_print("(ui_transaction) update\n") );
+	DB( g_print("\n[ui-transaction] update\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -93,7 +93,7 @@ void deftransaction_set_amount_from_split(GtkWidget *widget, gdouble amount)
 {
 struct deftransaction_data *data;
 
-	DB( g_print("(ui_transaction) set_amount_from_split\n") );
+	DB( g_print("\n[ui-transaction] set_amount_from_split\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -113,13 +113,13 @@ struct deftransaction_data *data;
 Transaction *entry;
 gchar *tagstr, *txt;
 
-	DB( g_print("(ui_transaction) set\n") );
+	DB( g_print("\n[ui-transaction] set\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
 	entry = data->ope;
 
-	DB( g_print(" -> ope=%p data=%p tags:%p\n", data->ope, data, entry->tags) );
+	DB( g_print(" - ope=%p data=%p tags:%p\n", data->ope, data, entry->tags) );
 
 	//DB( g_print(" set date to %d\n", entry->date) );
 	//g_object_set(GTK_DATE_ENTRY(data->PO_date), "date", (guint32)entry->ope_Date);
@@ -139,7 +139,7 @@ gchar *tagstr, *txt;
 
 	tagstr = transaction_tags_tostring(entry);
 
-	DB( g_print(" -> tags: '%s'\n", txt) );
+	DB( g_print(" - tags: '%s'\n", txt) );
 
 	txt = (tagstr != NULL) ? tagstr : "";
 	gtk_entry_set_text(GTK_ENTRY(data->ST_tags), txt);
@@ -155,7 +155,7 @@ gchar *tagstr, *txt;
 
 	gtk_combo_box_set_active(GTK_COMBO_BOX(data->NU_mode), entry->paymode);
 
-	DB( g_print(" -> acc is: %d\n", gtk_combo_box_get_active(GTK_COMBO_BOX(data->PO_acc)) ) );
+	DB( g_print(" - acc is: %d\n", gtk_combo_box_get_active(GTK_COMBO_BOX(data->PO_acc)) ) );
 }
 
 
@@ -167,13 +167,13 @@ gchar *txt;
 gdouble value;
 gint active;
 
-	DB( g_print("(ui_transaction) get\n") );
+	DB( g_print("\n[ui-transaction] get\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
 	entry = data->ope;
 
-	DB( g_print(" -> ope = %p\n", entry) );
+	DB( g_print(" - ope = %p\n", entry) );
 
 	//DB( g_print(" get date to %d\n", entry->ope_Date) );
 	entry->date = gtk_date_entry_get_date(GTK_DATE_ENTRY(data->PO_date));
@@ -232,7 +232,7 @@ gint active;
 
 	/* tags */
 	txt = (gchar *)gtk_entry_get_text(GTK_ENTRY(data->ST_tags));
-	DB( g_print(" -> tags: '%s'\n", txt) );
+	DB( g_print(" - tags: '%s'\n", txt) );
 	transaction_tags_parse(entry, txt);
 
 	entry->status = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_status));
@@ -265,7 +265,7 @@ struct deftransaction_data *data;
 gushort paymode;
 gdouble amount;
 
-	DB( g_print("(ui_transaction) amount focus-out-event %d\n", gtk_widget_is_focus(widget)) );
+	DB( g_print("\n[ui-transaction] amount focus-out-event %d\n", gtk_widget_is_focus(widget)) );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -290,7 +290,7 @@ guint count, i;
 Split *split;
 gdouble value;
 
-	DB( g_print("(ui_transaction) toggleamount\n") );
+	DB( g_print("\n[ui-transaction] toggleamount\n") );
 
 	if(icon_pos == GTK_ENTRY_ICON_PRIMARY)
 	{
@@ -322,7 +322,7 @@ static void deftransaction_button_split_cb(GtkWidget *widget, gpointer user_data
 struct deftransaction_data *data;
 gdouble amount;
 
-	DB( g_print("(ui_transaction) doing split\n") );
+	DB( g_print("\n[ui-transaction] doing split\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -340,7 +340,7 @@ struct deftransaction_data *data;
 gboolean sensitive;
 guint kacc, kdst;
 
-	DB( g_print("(ui_transaction) update transfer\n") );
+	DB( g_print("\n[ui-transaction] update transfer\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -390,7 +390,7 @@ static void deftransaction_update_accto(GtkWidget *widget, gpointer user_data)
 struct deftransaction_data *data;
 guint kacc;
 
-	DB( g_print("(ui_transaction) update accto\n") );
+	DB( g_print("\n[ui-transaction] update accto\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -415,7 +415,7 @@ gint payment;
 gint page;
 gboolean sensitive;
 
-	DB( g_print("(ui_transaction) paymode change\n") );
+	DB( g_print("\n[ui-transaction] paymode change\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -427,9 +427,9 @@ gboolean sensitive;
 	{
 	gboolean expense = (gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount)) > 0 ? FALSE : TRUE);
 
-		DB( g_print(" -> payment: %d\n", PAYMODE_CHECK) );
-		DB( g_print(" -> expense: %d\n", expense) );
-		DB( g_print(" -> acc is: %d\n", ui_acc_comboboxentry_get_key(GTK_COMBO_BOX(data->PO_acc)) ) );
+		DB( g_print(" - payment: %d\n", PAYMODE_CHECK) );
+		DB( g_print(" - expense: %d\n", expense) );
+		DB( g_print(" - acc is: %d\n", ui_acc_comboboxentry_get_key(GTK_COMBO_BOX(data->PO_acc)) ) );
 
 		if(payment == PAYMODE_CHECK)
 		{
@@ -440,7 +440,7 @@ gboolean sensitive;
 			guint cheque;
 			gchar *cheque_str;
 
-				DB( g_print(" -> should fill cheque number for account %d\n", active) );
+				DB( g_print(" - should fill cheque number for account %d\n", active) );
 
 				//#1410166
 				if( active > 0 )
@@ -511,7 +511,7 @@ Transaction *entry;
 Archive *arc;
 gint n_arc;
 
-	DB( g_print("(ui_transaction) fill from\n") );
+	DB( g_print("\n[ui-transaction] fill from\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 	entry = data->ope;
@@ -567,7 +567,8 @@ gboolean result;
 
 				DB( g_print(" - old_txn: kacc=%d kxferacc=%d\n", old_txn->kacc, old_txn->kxferacc) );
 				
-				ltxn = transaction_xfer_child_strong_get(old_txn);
+				//#1584342 was faultly old_txn
+				ltxn = transaction_xfer_child_strong_get(new_txn);
 				if(ltxn != NULL) //should never be the case
 				{
 					DB( g_print(" - strong link found, do sync\n") );
@@ -629,15 +630,15 @@ void deftransaction_set_transaction(GtkWidget *widget, Transaction *ope)
 struct deftransaction_data *data;
 
 
-	DB( g_print("(ui_transaction) set out transaction\n") );
+	DB( g_print("\n[ui-transaction] set transaction (from out)\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
 	data->ope = ope;
 
-	DB( g_print(" -> ope=%p data=%p\n", data->ope, data) );
+	DB( g_print(" - ope=%p data=%p\n", data->ope, data) );
 
-	DB( g_print(" -> call init\n") );
+	DB( g_print(" - call init\n") );
 
 	deftransaction_set(widget, NULL);
 	deftransaction_paymode(widget, NULL);
@@ -650,7 +651,7 @@ void deftransaction_dispose(GtkWidget *widget, gpointer user_data)
 {
 struct deftransaction_data *data;
 
-	DB( g_print("(ui_transaction) dispose\n") );
+	DB( g_print("\n[ui-transaction] dispose\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -661,7 +662,7 @@ struct deftransaction_data *data;
 static void deftransaction_setup(struct deftransaction_data *data)
 {
 
-	DB( g_print("(ui_transaction) setup\n") );
+	DB( g_print("\n[ui-transaction] setup\n") );
 
     gtk_window_set_title (GTK_WINDOW (data->window), _(CYA_OPERATION[data->type]));
 
@@ -824,7 +825,7 @@ GtkWidget *dialog, *content_area, *content_grid, *group_grid;
 GtkWidget *label, *widget;
 gint crow;
 
-	DB( g_print("(ui_transaction) new\n") );
+	DB( g_print("\n[ui-transaction] new\n") );
 
 	data = g_malloc0(sizeof(struct deftransaction_data));
 	
