@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2015 Maxime DOYEN
+ *  Copyright (C) 1995-2016 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -200,6 +200,23 @@ void ui_gtk_entry_set_text(GtkWidget *widget, gchar *text)
 		gtk_entry_set_text(GTK_ENTRY(widget), "");
 }
 
+void ui_gtk_entry_replace_text(GtkWidget *widget, gchar **storage)
+{
+const gchar *text;
+
+	DB( g_print(" storage is '%p' at '%p'\n", *storage, storage) );
+
+	/* free any previous string */
+	if( *storage != NULL )
+	{
+		g_free(*storage);
+	}
+
+	*storage = NULL;
+	text = gtk_entry_get_text(GTK_ENTRY(widget));
+	*storage = g_strdup(text);
+}
+
 
 GtkWidget *make_label_group(gchar *str)
 {
@@ -212,18 +229,24 @@ GtkWidget *label = gtk_label_new (str);
 }
 
 
+GtkWidget *make_label_widget(char *str)
+{
+GtkWidget *label = gtk_label_new_with_mnemonic (str);
+
+	gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
+	gtk_widget_set_halign (label, GTK_ALIGN_END);
+	return label;
+}
 
 
-/*
-**
-*/
 GtkWidget *make_label(char *str, gfloat xalign, gfloat yalign)
 {
-GtkWidget *label;
+GtkWidget *label = gtk_label_new_with_mnemonic (str);
 
-	label = gtk_label_new_with_mnemonic (str);
+	//todo: deprecated in 3.14
 	gtk_misc_set_alignment (GTK_MISC (label), xalign, yalign);
-
+	//gtk_label_set_xalign(GTK_LABEL(label), xalign);
+	//gtk_label_set_yalign(GTK_LABEL(label), yalign);
 	return label;
 }
 
@@ -238,10 +261,6 @@ GtkWidget *entry;
 	entry = gtk_entry_new ();
 	gtk_editable_set_editable (GTK_EDITABLE(entry), FALSE);
 	g_object_set(entry, "xalign", xalign, NULL);
-
-	//entry = gtk_label_new(NULL);
-	//gtk_misc_set_padding (entry, 4, 2);
-	//gtk_misc_set_alignment(entry, xalign, 0.5);
 	return entry;
 }
 
@@ -406,12 +425,12 @@ GtkAdjustment *adj;
 }
 
 
-GtkWidget *make_euro(GtkWidget *label)
+GtkWidget *make_exchange_rate(GtkWidget *label)
 {
 GtkWidget *spinner;
 GtkAdjustment *adj;
 
-	adj = (GtkAdjustment *) gtk_adjustment_new (0.0, -G_MAXINT32, G_MAXINT32, 0.01, 1.0, 0.0);
+	adj = (GtkAdjustment *) gtk_adjustment_new (0.0, 0.0, 99999, 0.01, 1.0, 0.0);
 	spinner = gtk_spin_button_new (adj, 1.0, 6);
 	//gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (spinner), TRUE);
 	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinner), TRUE);
@@ -842,34 +861,65 @@ gchar *get_paymode_icon_name(gint index)
 /*
 ** Make a paymode combobox widget
 */
-GtkWidget *make_paymode(GtkWidget *label)
+
+static void
+paymode_set_sensitive (GtkCellLayout   *cell_layout,
+	       GtkCellRenderer *cell,
+	       GtkTreeModel    *tree_model,
+	       GtkTreeIter     *iter,
+	       gpointer         data)
 {
-GtkListStore  *store;
-GtkTreeIter    iter;
+  GtkTreePath *path;
+  gint *indices;
+  gboolean sensitive;
+
+  path = gtk_tree_model_get_path (tree_model, iter);
+  indices = gtk_tree_path_get_indices (path);
+  sensitive = (indices[0] == PAYMODE_INTXFER) ? FALSE : TRUE;  
+  gtk_tree_path_free (path);
+  
+
+  g_object_set (cell, "sensitive", sensitive, NULL);
+}
+
+
+
+static GtkWidget *make_paymode_internal(GtkWidget *label, gboolean intxfer)
+{
+GtkListStore *store;
+GtkTreeIter iter;
 GtkWidget *combobox;
-GtkCellRenderer    *renderer;
+GtkCellRenderer *renderer, *r1, *r2;
 guint i;
 
-	//store
 	store = gtk_list_store_new (
 		NUM_LST_PAYMODE,
 		G_TYPE_STRING,
 		G_TYPE_STRING
 		);
 
-	//combobox
 	combobox = gtk_combo_box_new_with_model(GTK_TREE_MODEL(store));
 
-	//column 1
-	renderer = gtk_cell_renderer_pixbuf_new();
+	renderer = r1 = gtk_cell_renderer_pixbuf_new();
 	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(combobox), renderer, FALSE);
 	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT(combobox), renderer, "icon-name", LST_PAYMODE_ICONNAME);
 
-	renderer = gtk_cell_renderer_text_new();
+	renderer = r2 = gtk_cell_renderer_text_new();
 	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(combobox), renderer, FALSE);
 	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT(combobox), renderer, "text", LST_PAYMODE_LABEL);
 
-	gtk_combo_box_set_active(GTK_COMBO_BOX(combobox), 0);
+
+	if( intxfer == FALSE )
+	{
+		gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (combobox),
+						r1,
+						paymode_set_sensitive,
+						NULL, NULL);
+		gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (combobox),
+						r2,
+						paymode_set_sensitive,
+						NULL, NULL);
+	}
 
 	//populate our combobox model
 	for(i=0;i<NUM_PAYMODE_MAX;i++)
@@ -889,6 +939,20 @@ guint i;
 	return combobox;
 }
 
+
+
+
+GtkWidget *make_paymode(GtkWidget *label)
+{
+	return make_paymode_internal(label, TRUE);
+}
+
+GtkWidget *make_paymode_nointxfer(GtkWidget *label)
+{
+	return make_paymode_internal(label, FALSE);
+}
+
+
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 #define NUM_NAINEX_MAX 3
